pyhsm.buffer_cmd.YHSM_Cmd_Buffer_Random_Load

Package pyhsm :: Module buffer_cmd :: Class YHSM_Cmd_Buffer_Random_Load |
[frames] | no frames]

# Class YHSM_Cmd_Buffer_Random_Load

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_Buffer_Random_Load

Ask YubiHSM to generate a secret for a specific public_id

Generated secret is stored in YubiHSM's internal memory and is retreived using YHSM_Cmd_Blob_Generate.

Instance Methods
__init__(self, stick, num_bytes, offset=0) The base class for all YSM_ commands. |
parse_result(self, data) Return True if the public_id in the response matches the one in the request. |
Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, num_bytes, offset=0) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
Return True if the public_id in the response matches the one in the request. Overrides: cmd.YHSM_Cmd.parse_result